@@ -48,7 +48,7 @@ class TQGroupBox;
  * @version 0.7.0
  */
 class KNutFrontPanel : public TQFrame  {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
 
