@@ -72,7 +72,7 @@ KNutPrintUpsVar::KNutPrintUpsVar(KNutNet* const upsNet, const bool useDescriptio
     table = new TDEListView(page);
     table->setRootIsDecorated(true);
 
-    table->setAllColumnsShowFocus( TRUE );
+    table->setAllColumnsShowFocus( true );
     table->setFullWidth ( true );
 
     table->addColumn( i18n("Name") );
